# Colour hex case
Lowercase is easier to read for humans.

# Font family names
- We always want to use the recommendation, so let’s go with "single-where-recommended"
- Chose double over single because it seems to be the more popular convention

- The `font-family` property accepts a short list of special **keywords**: `inherit`, `serif`, `sans-serif`, `cursive`, `fantasy`, and `monospace`. If you wrap these words in quotes, the browser will not interpret them as keywords, but will instead look for a font by that name (e.g. will look for a `"sans-serif"` font) -- which is almost *never* what you want. Instead, you use these keywords to point to the built-in, generic fallbacks (right?). Therefore, *all of the options below enforce no quotes around these keywords*. (If you actually want to use a font named `"sans-serif"`, turn this rule off.)
- Quotes are **recommended** [in the spec](https://www.w3.org/TR/CSS2/fonts.html#font-family-prop) with "font family names that contain white space, digits, or punctuation characters other than hyphens".
- Quotes are **required** around font-family names when they are not [valid CSS identifiers](https://www.w3.org/TR/CSS2/syndata.html#value-def-identifier). For example, a font family name requires quotes around it if it contains `$`, `!`, or `/`, but does not require quotes just because it contains spaces or a (non-initial) number or underscore. *You can probably bet that almost every font family name you use **will** be a valid CSS identifier*.

For more on these subtleties, read ["Unquoted font family names in CSS"](https://mathiasbynens.be/notes/unquoted-font-family), by Mathias Bynens.

[More info](https://github.com/stylelint/stylelint/blob/master/src/rules/font-family-name-quotes/README.md)

# Font weight notation
These can be either but let’s go with numbers because a numeric scale is clearer

# Functions
## Linear gradients
- A common mistake (matching outdated non-standard syntax) is to use just a side-or-corner without the preceding `to`.

# Number
## Number max precision
- Normally I would set this to 3 but our media queries use 4 to match to pixel values

# Selector
- Chose :: because it’s used in documentation examples and is the correct notation, despite it being longer
- ":" is technically deprecated in CSS3
- See the left hand side of https://developer.mozilla.org/en-US/docs/Web/CSS/:hover for a list of pseudo-classes and pseudo-elements

> The :: notation was chosen for pseudo-elements to establish a discrimination between pseudo-classes (which subclass existing elements) and pseudo-elements (which are elements not represented in the document tree).

> However, for compatibility with existing style sheets, user agents also accept the previous one-colon notation for pseudo-elements introduced in CSS levels 1 and 2 (namely, :first-line, :first-letter, :before and :after).